diff --git a/.gitignore b/.gitignore
index befba5a20..880e63a7f 100644
--- a/.gitignore
+++ b/.gitignore
@@ -234,7 +234,6 @@ pip-log.txt
#Mr Developer
.mr.developer.cfg
-MediaBrowser.WebDashboard/dashboard-ui/.idea/
/.vs
##########
diff --git a/.gitmodules b/.gitmodules
index 31a58ecf1..7aeb94dfc 100644
--- a/.gitmodules
+++ b/.gitmodules
@@ -1,3 +1,6 @@
[submodule "ThirdParty/taglib-sharp"]
path = ThirdParty/taglib-sharp
url = https://github.com/mono/taglib-sharp.git
+[submodule "MediaBrowser.WebDashboard/jellyfin-web"]
+ path = MediaBrowser.WebDashboard/jellyfin-web
+ url = https://github.com/jellyfin/jellyfin-web.git
diff --git a/MediaBrowser.Controller/IServerApplicationPaths.cs b/MediaBrowser.Controller/IServerApplicationPaths.cs
index 5fb7968dd..e97943cbe 100644
--- a/MediaBrowser.Controller/IServerApplicationPaths.cs
+++ b/MediaBrowser.Controller/IServerApplicationPaths.cs
@@ -12,7 +12,6 @@ namespace MediaBrowser.Controller
///
/// Gets the application resources path. This is the path to the folder containing resources that are deployed as part of the application
- /// For example, this folder contains dashboard-ui and swagger-ui
///
/// The application resources path.
string ApplicationResourcesPath { get; }
diff --git a/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj b/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj
index 855b8b627..c5367ba75 100644
--- a/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj
+++ b/MediaBrowser.WebDashboard/MediaBrowser.WebDashboard.csproj
@@ -10,7 +10,7 @@
-
+
PreserveNewest
diff --git a/MediaBrowser.WebDashboard/jellyfin-web b/MediaBrowser.WebDashboard/jellyfin-web
new file mode 160000
index 000000000..4678528d0
--- /dev/null
+++ b/MediaBrowser.WebDashboard/jellyfin-web
@@ -0,0 +1 @@
+Subproject commit 4678528d0028685b45c7c6daa2e24b72a363535b
diff --git a/MediaBrowser.WebDashboard/Api/DashboardService.cs b/MediaBrowser.WebDashboard/Api/DashboardService.cs
index 58d02ef04..38a789580 100644
--- a/MediaBrowser.WebDashboard/Api/DashboardService.cs
+++ b/MediaBrowser.WebDashboard/Api/DashboardService.cs
@@ -138,9 +138,9 @@ namespace MediaBrowser.WebDashboard.Api
}
///
/// Gets the dashboard UI path.
///
- /// The dashboard UI path.
+ /// The path for the web interface.
public string DashboardUIPath
{
get
@@ -150,7 +150,7 @@ namespace MediaBrowser.WebDashboard.Api
return _serverConfigurationManager.Configuration.DashboardSourcePath;
}
- return Path.Combine(_serverConfigurationManager.ApplicationPaths.ApplicationResourcesPath, "dashboard-ui");
+ return Path.Combine(_serverConfigurationManager.ApplicationPaths.ApplicationResourcesPath, "jellyfin-web", "src");
}
}
@@ -138,9 +138,9 @@ namespace MediaBrowser.WebDashboard.Api
}
///
- /// Gets the dashboard UI path.
+ /// Gets the path for the web interface.
///